<?php
define( 'EASE_THEME_FOLDER', 'ease' );
define( 'EASE_THEME_NAME', 'Ease' );
define( 'EASE_VERSION', '0.7' );
define( 'EASE_UPGRADE_COUNT', 2 );
define( 'EASE_THEME_DIR', get_template_directory() . DIRECTORY_SEPARATOR );
define( 'EASE_URL', get_template_directory_uri());
define( 'EASE_INCLUDES', get_template_directory() . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR );

require_once( EASE_INCLUDES . 'tools.php' );
require_once( EASE_INCLUDES . 'theme-options.php' );
require_once( EASE_INCLUDES . 'admin-ajax.php' );

if ( ! function_exists( 'excerpt_read_more_link' ) ) {
	function excerpt_read_more_link( $output ) {
		global $post;
		return $output . '<span class="continue-reading"><a href="'. get_permalink($post->ID) . '">' . 'Continue reading &rarr;' . '</a></span>';
	}
}
add_filter('the_excerpt', 'excerpt_read_more_link');

if ( ! function_exists( 'ease_front_scripts' ) ) {
    function ease_front_scripts() {
        $options = ease_get_theme_options();
        wp_enqueue_style( 'ease_color', EASE_URL . '/scripts/' . $options['color_scheme'] . '.css', array(), '0.7' );
    }
}
add_action( 'wp_enqueue_scripts', 'ease_front_scripts' );

if ( ! function_exists( 'ease_init' ) ) {
	function ease_init() {

    ease_checkdb();
	
    $options = ease_get_theme_options();
    $cs = ease_get_color_scheme_list();
    
	if ( ! isset($content_width) ) {
		$content_width = 520;
	}
    
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	register_nav_menu( 'primary', 'Primary menu' );
	
	$defaults = array(
		'default-image'          => '',
		'width'                  => 0,
		'height'                 => 0,
		'flex-height'            => true,
		'flex-width'             => true,
		'default-text-color'     => $cs[$options['color_scheme']]['hcolor'],
		'header-text'            => true,
		'uploads'                => true,
		'wp-head-callback'       => 'ease_header_cb',
		'admin-head-callback'    => 'ease_adminpreview_head_cb',
		'admin-preview-callback' => 'ease_admin_preview_cb',
	);
	
	add_theme_support( 'custom-header', $defaults );
	
	add_theme_support( 'custom-background', array(
		'default-color' => $cs[$options['color_scheme']]['bgcolor'],
        'default-image' => EASE_URL . '/images/' . $options['color_scheme'] . '-bg.png'
	) );
	
	add_editor_style();
	
	}
}
add_action( 'after_setup_theme', 'ease_init' );

if ( ! function_exists( '' ) ) {
	function ease_activate( $oldname, $oldtheme = false ) {
		if ( EASE_THEME_NAME != $oldname ) {
		
		}		
	}
}
add_action( 'after_switch_theme', 'ease_activate', 10, 2);

if ( ! function_exists( 'ease_deactivate' ) ) {
	function ease_deactivate( $newname, $newtheme ) {
		if ( EASE_THEME_NAME != $newname ) {
		
		}
	}
}
add_action( 'switch_theme', 'ease_deactivate', 10, 2 );

if ( ! function_exists( 'ease_widget_init' ) ) {
	function ease_widget_init() {
	
	register_sidebar( array(
		'name'			=> 'Main Sidebar',
		'id'			=> 'sidebar1',
		'description'	=> 'This is the main sidebar',
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h3 class="widget-title">',
		'after_title'	=> '</h3>'
	) );
	
	register_sidebar( array(
		'name'			=> 'Footer sidebar 1',
		'id'			=> 'sidebar2',
		'description'	=> 'Optional sidebar for the footer',
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h3 class="widget-title">',
		'after_title'	=> '</h3>'
	) );
			
	register_sidebar( array(
		'name'			=> 'Footer sidebar 2',
		'id'			=> 'sidebar3',
		'description'	=> 'Optional sidebar for the footer',
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h3 class="widget-title">',
		'after_title'	=> '</h3>'
	) );		
	
	register_sidebar( array(
		'name'			=> 'Footer sidebar 3',
		'id'			=> 'sidebar4',
		'description'	=> 'Optional sidebar for the footer',
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h3 class="widget-title">',
		'after_title'	=> '</h3>'
	) );
	
	register_sidebar( array(
		'name'			=> 'Header sidebar',
		'id'			=> 'sidebar5',
		'description'	=> 'Header sidebar, between site title and header image.',
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h3 class="widget-title">',
		'after_title'	=> '</h3>'
	) );
	
	}
}
add_action( 'widgets_init', 'ease_widget_init');

if ( ! function_exists( 'ease_wp_head' ) ) {
    function ease_wp_head() {
    ?>
        <link rel="stylesheet" type="text/css" href="http://fonts.googleapis.com/css?family=Open+Sans">
    <?php
    }
}
add_action( 'wp_head', 'ease_wp_head' );
