<?php
function ease_optpage_cb() {
    global $ease_optpage;
	$ease_optpage = add_theme_page( 'Theme Options', 'Theme options', 'edit_theme_options', 'theme_options', 'ease_render_optpage_cb' );
	if ( ! $ease_optpage )
		return;
	add_action( "load-{$ease_optpage}", 'ease_optpage_loaded' );
    add_action( "admin_head-{$ease_optpage}", 'ease_admin_head_cb' );
}
add_action( 'admin_menu', 'ease_optpage_cb' );

function ease_admin_head_cb() {
$ease_nonce = wp_create_nonce( 'ease_reset_cs' );
?>
<script type="text/javascript">
/* <![CDATA[ */
    ease_ajax_data = {
        ease_reset_cs : {
            action : 'ease_reset_cs',
            url : "<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>",
            nonce : '<?php echo $ease_nonce; ?>',
            target : '#reset-cs',
            preloader : '<?php echo admin_url( '/images/loading.gif' ); ?>',
            preloaderTarget : '#reset-cs-button',
        }
    }
/* ]]> */
</script>
<?php
}

function ease_optpage_loaded() {

}

function ease_enqueue_admin_scripts( $hook ) {
    global $ease_optpage;
	if ( $ease_optpage == $hook ) {
        wp_enqueue_style( 'ease_admin_css', get_template_directory_uri() . '/scripts/admin.css' );
        wp_enqueue_script( 'ease_admin_js', get_template_directory_uri() . '/scripts/admin.js' );
    }
}

add_action( 'admin_enqueue_scripts', 'ease_enqueue_admin_scripts' );

function ease_admin_init() {

	register_setting(
		'ease_options_group',
		'ease_options',
		'ease_validate'
	);	
	add_settings_section(
		'ease_main_section',
		'',
		'__return_false',
		'ease_options_page'
	);
	add_settings_field(
		'credit',
		'Theme credit',
		'ease_render_credit_cb',
		'ease_options_page',
		'ease_main_section'
	);
    add_settings_field(
        'color',
        'Color scheme',
        'ease_render_colorscheme_cb',
		'ease_options_page',
		'ease_main_section'
    );
	add_settings_field(
		'blog_grid',
		'Posts front page&#39;s layout',
		'ease_render_bloggrid_cb',
		'ease_options_page',
		'ease_main_section'
	);
	add_settings_field(
		'archives_grid',
		'Archives pages layout',
		'ease_render_archivesgrid_cb',
		'ease_options_page',
		'ease_main_section'
	);
}
add_action( 'admin_init', 'ease_admin_init' );

/**
* Setting fields callbacks
*/

function ease_render_credit_cb() {
	$options = ease_get_theme_options();
	$desc = "Untick to remove the ease theme credit link on the footer.";
	?>
	<div id="theme-credits-block" class="option-block">
		<input type="checkbox" name="ease_options[credit]" <?php checked( $options['theme_credit'] ); ?> />
		<p><em><?php echo esc_attr( $desc ); ?></em></p>
	</div>
	<?php
}

function ease_render_colorscheme_cb() {
	$options = ease_get_theme_options();
    ?>
    <div id="color-scheme-block" class="option-block">
    <?php foreach ( ease_get_color_scheme_list() as $key => $value ) : ?>
        <div class="color-scheme-container">
            <label><em><?php echo $key; ?></em>
                <input type="radio" name="ease_options[colorscheme]" value="<?php echo $key; ?>" <?php checked($key, $options['color_scheme']); ?> />
                <img class="color-scheme-thumbnail" src="<?php echo esc_url( $value['thumb'] ); ?>" alt="<?php echo $key ?>" />
            </label>
        </div>
    <?php endforeach; ?>
    <div id="reset-cs" style="clear: both; border-top: 1px solid #dfdfdf; position: relative;"><p><em style="margin: 1.5em;">Reset header text color and background image to default values of the current color scheme ? </em><a href="#" class="button" id="reset-cs-button">Reset</a></p></div>
    </div>
    <?php
}

function ease_render_bloggrid_cb() {
	$options = ease_get_theme_options();
	?>
	<div id="posts-grid" class="option-block">
        <?php foreach ( ease_get_grid_list() as $key => $value ) : ?>
            <div class="grid-container">
                <label><em><?php echo $value['desc']; ?></em>
                    <input type="radio" value="<?php echo $key; ?>" name="ease_options[postsgrid]" <?php checked( $options['blog']['grid'], $value['checked'] ); ?> />
                    <img class="grid-thumbnail" src="<?php echo esc_url( $value['thumb'] ); ?>" alt="<?php echo $key; ?>" />
                </label>
           </div>
        <?php endforeach; ?>
	</div>
	<?php
}

function ease_render_archivesgrid_cb() {
	$options = ease_get_theme_options();
	$desc = "Use a grid layout for archives pages.";
	?>
	<div id="archives-grid" class="option-block">
        <?php foreach ( ease_get_grid_list() as $key => $value ) : ?>
            <div class="grid-container">
                <label><em><?php echo $value['desc']; ?></em>
                    <input type="radio" value="<?php echo $key; ?>" name="ease_options[archivesgrid]" <?php checked( $options['archives']['grid'], $value['checked'] ); ?> />
                    <img class="grid-thumbnail" src="<?php echo esc_url( $value['thumb'] ); ?>" alt="<?php echo $key; ?>" />
                </label>
           </div>
        <?php endforeach; ?>
	</div>
	<?php
}

function ease_render_optpage_cb() {
	?>
	<div id="ease-wrapper" class="postbox">
	<form id="theme-options-form" method="post" action="options.php">
	<h3>Theme Options</h3><!--
	<?php //settings_errors(); ?>-->
	<?php
		settings_fields( 'ease_options_group' );
		do_settings_sections( 'ease_options_page' );
		submit_button();
	?>
	</form>
	</div>
	<?php
}

/**
* Setting fields validation.
*/
function ease_validate( $input ){
	$output = ease_get_theme_options();
	if ( isset( $input['credit'] ) ) {
		$output['theme_credit'] = true;
	} else {
		$output['theme_credit'] = false;
	}
    
	$output['blog']['grid'] = ( 'grid' == $input['postsgrid'] ) ? true : false;
	$output['archives']['grid'] = ( 'grid' == $input['archivesgrid'] ) ? true : false;
    
    if ( array_key_exists($input['colorscheme'], ease_get_color_scheme_list() ) ) {
        if ( $output['color_scheme'] != $input['colorscheme'] ) {
            $cs = ease_get_color_scheme_list();
            set_theme_mod( 'header_textcolor', $cs[$input['colorscheme']]['hcolor'] );
        }
        $output['color_scheme'] = $input['colorscheme'];
    }
	return $output;
}
