<?php
/**
* returns default options
*/
function ease_default_options() {
    $options = array(
        'theme_credit' => true,
        'color_scheme' => 'red',// 0.7
        'blog' => array( 'grid' => true ),
        'archives' => array( 'grid' => true ),
        'version' => EASE_VERSION
    );
	return $options;
}

/**
* returns theme options
*/
function ease_get_theme_options() {
	return get_option( 'ease_options', ease_default_options() );
}

/**
* Version upgrade management
*/
function ease_checkdb() {
	$options = get_option( 'ease_options' );
    
	if ( ! is_array( $options ) ) {
		$options = ease_default_options();
    }
    
    $version_counter = 0;
    $debug = '';
	while ( EASE_VERSION != $options['version'] ) {
        $debug .= "Counter : $version_counter , ";
        if ( EASE_UPGRADE_COUNT < $version_counter ) {
            return;
        }
        switch ( $options['version'] ) {
            default :
                $options = ease_append_options($options, ease_default_options());
                $options['version'] = EASE_VERSION;
                $version_counter++;
        }
	}
    update_option( 'ease_options', $options );
}

function ease_append_options($arr1, $arr2) {
    foreach( $arr2 as $key => $value ) {
        if ( !isset( $arr1[$key] ) ) {
            $arr1[$key] = $value;
        } else {
            if ( is_array($value) ) {
                ease_append_options($arr1[$key], $arr2[$key]);
            }
        }
    }
    return $arr1;
}

/**
* Shortcut for displaying author and date in post/page.
*/
function ease_author() {
	printf( '<div class="entry-meta">By <a title="%1$s" href="%2$s">%3$s</a> on <span class="entry-date">%4$s</span></div>',
		esc_attr( sprintf( 'View all post by %s', get_the_author() ) ),
		get_author_posts_url( get_the_author_meta( 'ID' ) ),
		get_the_author(),
		esc_attr( get_the_date() )
	);
}


/**
* Shortcut for displaying categories and tags in post/page.
*/
function ease_category() {
	$cat = get_the_category_list( ', ' );
	$tag = get_the_tag_list( '', ', ' );
	if ( ! empty( $cat ) && ! empty( $tag ) )
        printf( '<div class="entry-meta">Posted in %1$s | Tagged %2$s</div>', $cat, $tag );
	if ( ! empty( $cat ) && empty( $tag ) )
        printf( '<div class="entry-meta">Posted in %1$s</div>', $cat );
	if ( empty( $cat ) && ! empty( $tag ) )
        printf( '<div class="entry-meta">This post was tagged %1$s</div>', $tag );
}

/**
* Navigation links for archive or categoryy pages.
*/
function ease_posts_nav( $id ) {
	global $wp_query;	
	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="<?php echo $id; ?>" class="pagination">Page:
			<?php
			
			$big = 999999;
			echo paginate_links( array(
				'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
				'format' => '?paged=%#%',
				'current' => max( 1, get_query_var('paged') ),
				'total' => $wp_query->max_num_pages
			) );
			
			?>
		</nav>
	<?php endif;
}

/**
* Displays the appropriate footer-class.
*/
function ease_footer_class() {
	$count = 0;
	$class = 'no-sidebar';
	
	if ( is_active_sidebar( 'sidebar2' ) )
		$count++;
	if ( is_active_sidebar( 'sidebar3' ) )
		$count++;
	if ( is_active_sidebar( 'sidebar4' ) )
		$count++;
	
	switch ( $count ) {
		case 1 :
			$class = 'one-sidebar';
			break;
		case 2 :
			$class = 'two-sidebars';
			break;
		case 3 :
			$class = 'three-sidebars';
			break;
		default :
			$class = 'no-sidebar';
	}
	return $class;
}

/**
* Custom header css in the "head" section.
*/
function ease_header_cb() {
	$color = get_header_textcolor();
	?>
	<style type="text/css">		
		#site-head hgroup{
			margin: 0.6em;
			font-family: Lucida, "Times New Roman", Times, serif;
		}
		
		#site-title {
			font-size: 2.4em;
			margin: 0.3em 0;
			color: #<?php echo $color; ?>;
		}
		
		#site-description {
			font-size: 1.2em;
			text-decoration: none;
			margin: 0.3em 0;
			color: #<?php echo $color; ?>;
		}
	</style>
	<?php
}

/**
* comment display.
*/
function ease_comments_cb( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback testing">
		<p>Pingback: <?php comment_author_link(); ?> | <?php edit_comment_link( 'Edit this comment', '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
			ob_start();
			comment_class();
			$com_class = ob_get_clean();
	?>
	<li <?php echo $com_class; ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>">
			<footer class="comment-meta">
				<div class="comment-author">
					<?php
						$avatar_size = 64;
						if ( '0' != $comment->comment_parent && false === stripos( $com_class, 'depth-1' ) )
							$avatar_size = 32;

						echo get_avatar( $comment, $avatar_size );
						printf( 'By %1$s on %2$s',
							sprintf( '<span class="author">%s</span>', get_comment_author_link() ),
							sprintf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								sprintf( '%1$s at %2$s', get_comment_date(), get_comment_time() )
							)
						);
					?>
				</div><!-- .comment-author -->
				<p><?php edit_comment_link('Edit this comment', '<span class="edit-link">', '</span>' ); ?></p>
				<?php if ( $comment->comment_approved == '0' ) : ?>
				<p class="comment-awaiting-moderation"><?php echo 'Your comment is awaiting moderation.'; ?></p>
				<?php endif; ?>
				
			</footer>
			
			<div class="comment-content"><?php comment_text(); ?></div>
			
			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => 'Reply <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article>
	<?php
			break;
	endswitch;
}

/**
* Shortcut for a textual comments count in a post/page.
*/
function ease_comment_count() {
	global $post;
	if ( empty( $post->ID ) )
		return;
	$comment_count = wp_count_comments( $post->ID );
	$count = $comment_count->total_comments;
	switch ( $count ) {
		case 0:
			echo "No comment";
			break;
		case 1:
			echo "One comment";
			break;
		default:
			echo "$count comments";
	}
}

/**
* css for admin preview of the custom header.
*/
function ease_adminpreview_head_cb() {
$color = get_header_textcolor();
$options = ease_get_theme_options();
$mods = get_theme_mods();
?>
<style type="text/css">
	#admin-header-preview {
		border: 1px solid #eee;
        <?php
            if ( isset( $mods['background_image'] ) ) {
                if ( '' != $mods['background_image'] ) {
                    /**
                    * Background image has been defined via the background admin page under the appearance menu (and there is a background image).
                    */
                    echo 'background: url("' . $mods['background_image'] . '") ' . $mods['background_repeat'] . ';';
                    echo 'background-attachment: ' . $mods['background_attachment'] . ';';
                    echo 'background-position: top ' . $mods['background_position_x'] . ';';
                }
            } else { // Display the default background image corresponding to the current color scheme.
                echo 'background-image: url("' . EASE_URL . '/images/' . $options['color_scheme'] . '-bg.png");';
                echo 'background-repeat: repeat;';
                echo 'background-attachment: scroll;';
                echo 'background-positiont: top left;';
            }
        ?>
	}
	
    #preview-wrapper {
        padding: 1em 0em;
        border: 1px solid;
        margin: 1.5em auto;
        border-radius: 3px;
        width: 92%;
        <?php
            switch ( $options['color_scheme'] ) {
                case 'light' :
                    echo 'border-color: #dfdfdf;';
                    break;
                case 'dark' :
                    echo 'border-color: #5b5b5b;';
                    break;
                case 'red' :
                    echo 'border-color: #dfdfdf;';
                    break;
                default:
            }
        ?>
    }
    
	#site-head hgroup{
		margin: 0.6em;
        font-family: Calibri, Verdana, sans-serif;
	}
	
	#site-title {
		font-size: 2.4em;
		margin: 0.3em 0;
		color: #<?php echo $color; ?>;
	}
	
	#site-description {
		font-size: 1.2em;
		text-decoration: none;
		margin: 0.3em 0;
		color: #<?php echo $color; ?>;
	}
</style>
<?php
}

/**
* Displaying of the custom-header preview in admin panel.
*/
function ease_admin_preview_cb() {
?>
<div id="admin-header-preview">
    <div id="preview-wrapper">
        <header id="site-head">
            <?php if ( 'blank' != get_header_textcolor() ) : ?>
            <hgroup id="site-head">
                <h2 id="site-title"><?php bloginfo( 'name' ) ?></h2>
                <h3 id="site-description"><?php bloginfo( 'description' ) ?></h3>
            </hgroup>
            <?php endif; ?>
            <?php if ( get_header_image() ) : ?>
            <img src="<?php header_image(); ?>" id="header-background" role="banner" alt="" style="width: 100%;" />
            <?php endif; ?>
        </header>
    </div>
</div>
<?php
}

/**
* Tools for setting fields in the theme option page.
*/

function ease_get_color_scheme_list() {
    $scheme = array(
        'red' => array( 'thumb' => EASE_URL . '/images/red.png', 'bgcolor' => 'fff', 'hcolor' => '000' ),
        'light' => array( 'thumb' => EASE_URL . '/images/light.png', 'bgcolor' => 'fff', 'hcolor' => '000' ),
        'dark' => array( 'thumb' => EASE_URL . '/images/dark.png', 'bgcolor' => '000', 'hcolor' => 'e5e5e5' ),
    );
    return $scheme;
}

function ease_get_grid_list() {
    $grid = array(
        'nogrid' => array( 'desc' => 'One column layout', 'thumb' => EASE_URL . '/images/nogrid.png', 'checked' => false ),
        'grid' => array( 'desc' => 'Grid layout', 'thumb' => EASE_URL . '/images/grid.png', 'checked' => true ),
    );
    return $grid;
}
